@@ -88,14 +88,14 @@ def get_sim_voxels(name='fib1'):
     ----------
     >>> from dipy.data import get_sim_voxels
     >>> sv=get_sim_voxels('fib1')
-    >>> sv['data'].shape
-    (100, 102)
+    >>> sv['data'].shape == (100, 102)
+    True
     >>> sv['fibres']
     '1'
-    >>> sv['gradients'].shape
-    (102, 3)
-    >>> sv['bvals'].shape
-    (102,)
+    >>> sv['gradients'].shape == (102, 3)
+    True
+    >>> sv['bvals'].shape == (102,)
+    True
     >>> sv['snr']
     '60'
     >>> sv2=get_sim_voxels('fib2')
@@ -168,10 +168,10 @@ def get_sphere(name='symmetric362'):
     >>> from dipy.data import get_sphere
     >>> sphere = get_sphere('symmetric362')
     >>> verts, faces = sphere.vertices, sphere.faces
-    >>> verts.shape
-    (362, 3)
-    >>> faces.shape
-    (720, 3)
+    >>> verts.shape == (362, 3)
+    True
+    >>> faces.shape == (720, 3)
+    True
     >>> verts, faces = get_sphere('not a sphere name') #doctest: +IGNORE_EXCEPTION_DETAIL
     Traceback (most recent call last):
         ...
@@ -224,12 +224,12 @@ def get_data(name='small_64D'):
     >>> import nibabel as nib
     >>> img=nib.load(fimg)
     >>> data=img.get_data()
-    >>> data.shape
-    (6, 10, 10, 102)
-    >>> bvals.shape
-    (102,)
-    >>> bvecs.shape
-    (102, 3)
+    >>> data.shape == (6, 10, 10, 102)
+    True
+    >>> bvals.shape == (102,)
+    True
+    >>> bvecs.shape == (102, 3)
+    True
     """
 
     if name == 'small_64D':
