@@ -6,6 +6,8 @@ IO_DATA_PATH = abspath(pjoin(dirname(__file__),
                              '..', 'io', 'tests', 'data'))
 
 from .spherepoints import sphere_points
+from .decorators import doctest_skip_parser
+from numpy.testing import assert_array_equal
 
 # Allow failed import of nose if not now running tests
 try:
@@ -13,8 +15,10 @@ try:
 except ImportError:
     pass
 else:
-    from lightunit import ParametricTestCase, parametric
     from nose.tools import (assert_equal, assert_not_equal,
                             assert_true, assert_false, assert_raises)
-    
 
+
+def assert_arrays_equal(arrays1, arrays2):
+    for arr1, arr2 in zip(arrays1, arrays2):
+        assert_array_equal(arr1, arr2)
